==> ecodata-2.3-exec.jar: assets/knockout-dates.js <==
//# sourceMappingURL=knockout-dates.js.map
(function(){Date.prototype.toISOStringNoMillis=function(){function a(b){return 10>b?"0"+b:b}return this.getUTCFullYear()+"-"+a(this.getUTCMonth()+1)+"-"+a(this.getUTCDate())+"T"+a(this.getUTCHours())+":"+a(this.getUTCMinutes())+":"+a(this.getUTCSeconds())+"Z"};var a=new Date("2011-06-02T09:34:29+02:00");Date.fromISO=a&&1307000069E3===+a?function(a){return new Date(a)}:function(a){var b,d=/^(\d{4}\-\d\d\-\d\d([tT ][\d:\.]*)?)([zZ]|([+\-])(\d\d):(\d\d))?$/.exec(a)||[];if(d[1]){a=d[1].split(/\D/);b=
0;for(var e=a.length;b<e;b++)a[b]=parseInt(a[b],10)||0;--a[1];a=new Date(Date.UTC.apply(Date,a));if(!a.getDate())return NaN;d[5]&&(b=60*parseInt(d[5],10),d[6]&&(b+=parseInt(d[6],10)),"+"==d[4]&&(b*=-1),b&&a.setUTCMinutes(a.getUTCMinutes()+b));return a}return NaN}})();function isValidDate(a){return"[object Date]"!==Object.prototype.toString.call(a)?!1:!isNaN(a.getTime())}
function convertToSimpleDate(a,c){if(!a)return"";var b=a;"string"===typeof a&&(b=Date.fromISO(a));if(!isValidDate(b))return"";pad(b.getDate(),2);pad(b.getMonth()+1,2);b.getFullYear();a=pad(b.getDate(),2)+"-"+pad(b.getMonth()+1,2)+"-"+b.getFullYear();c&&(a=a+" "+pad(b.getHours(),2)+":"+pad(b.getMinutes(),2));return a}
function convertToIsoDate(a){if("string"===typeof a){if(20===a.length&&"Z"===a.charAt(19))return a;if(9<a.length){var c=a.substr(6,4),b=Number(a.substr(3,2))-1,d=a.substr(0,2),e=12<a.length?a.substr(11,2):0;a=15<a.length?a.substr(14,2):0;c=new Date(c,b,d,e,a);return isValidDate(c)?c.toISOStringNoMillis():""}return""}return"object"===typeof a?isValidDate(a)?a.toISOStringNoMillis():"":""}
function stringToDate(a){if("string"===typeof a){if(20===a.length&&"Z"===a.charAt(19))return Date.fromISO(a);if(9<a.length){var c=a.substr(6,4),b=Number(a.substr(3,2))-1,d=a.substr(0,2),e=12<a.length?a.substr(11,2):0;a=15<a.length?a.substr(14,2):0;return new Date(c,b,d,e,a)}}else if("object"===typeof a)return a}
(function(){ko.bindingHandlers.stopBinding={init:function(){return{controlsDescendantBindings:!0}}};ko.virtualElements.allowedBindings.stopBinding=!0;ko.extenders.simpleDate=function(a,c){a.date=ko.computed({read:function(){return Date.fromISO(a())},write:function(b){if(b){var c=a();b=convertToIsoDate(b);b!==c&&a(b)}else a("")}});a.formattedDate=ko.computed({read:function(){return convertToSimpleDate(a(),c)},write:function(b){if(b){var c=a();b=convertToIsoDate(b);b!==c&&a(b)}}});a.date(a());a.formattedDate(a());
return a};ko.bindingHandlers.datepicker={init:function(a,c,b){var d=$(a);b=ko.utils.unwrapObservable(c());b=convertToSimpleDate(b);d.is("input")?d.val(b):d.data("date",b);d.datepicker({format:"dd-mm-yyyy",autoclose:!0});d.parent().find(".open-datepicker").click(function(){d.datepicker("show")});b=function(a){var b=c();ko.isObservable(b)&&b(a.date)};ko.utils.registerEventHandler(a,"changeDate",b);ko.utils.registerEventHandler(a,"hide",b);ko.utils.registerEventHandler(a,"change",function(){var b=c();
ko.isObservable(b)&&(b(stringToDate(a.value)),$(a).trigger("blur"))})},update:function(a,c){if(a=$(a).data("datepicker"))c=ko.utils.unwrapObservable(c()),a.date=c,isNaN(a.date)||a.setDate(a.date)}}})();function pad(a,c){for(a=""+a;a.length<c;)a="0"+a;return a}ko.protectedObservable=function(a){var c=ko.observable(a),b=a;a=ko.dependentObservable({read:c,write:function(a){c(a)}});a.commit=function(){b=c()};a.reset=function(){c(b)};return a};
ko.bindingHandlers.clickToPickDate={init:function(a,c,b,d){var e=c(),f=$(a).attr("data-prompt")||"Click to edit";c=$('<i class="icon-calendar open-datepicker" title="Click to change date"></i>');e.originalValue=e.date();e.hasChanged=ko.computed(function(){var a=e.originalValue.getTime(),b=e.date().getTime();return a!=b&&(!isNaN(a)||!isNaN(b))});$(a).parent().append(c);ko.applyBindingsToNode(a,{text:ko.computed(function(){return""!==ko.utils.unwrapObservable(e)?e.formattedDate():f}),datepicker:e.date})}};
ko.bindingHandlers.clickToEdit={init:function(a,c){var b=c();c=document.createElement("a");var d=document.createElement("input"),e=$(a).attr("data-edit-on-dblclick"),f=$(a).attr("data-prompt")||(e?"Double-click to edit":"Click to edit");$(c).addClass($(a).attr("data-link-class"));$(d).addClass($(a).attr("data-input-class"));a.appendChild(c);a.appendChild(d);b.editing=ko.observable(!1);b.stopEditing=function(){$(d).blur();b.editing(!1)};a={text:ko.computed(function(){var a=ko.utils.unwrapObservable(b);
return""!==a?a:f}),visible:ko.computed(function(){return!b.editing()})};e?a.event={dblclick:b.editing.bind(null,!0)}:a.click=b.editing.bind(null,!0);ko.applyBindingsToNode(c,a);ko.applyBindingsToNode(d,{value:b,visible:b.editing,hasfocus:b.editing});$(d).keydown(function(a){13===a.which&&b.stopEditing()})}};
ko.bindingHandlers.ticks={init:function(a,c){var b=c();a=$(a).parent();var d;c=$('<div class="tick-controls btn-group btn-group-vertical"></div>');a.css("padding","4px");c.append($('<button class="up btn btn-mini"><i class="icon-chevron-up"></i></button>'));c.append($('<button class="down btn btn-mini"><i class="icon-chevron-down"></i></button>'));a.append(c);d=a.find("button");d.hide();ko.utils.registerEventHandler(a,"mouseover",function(){d.show()});ko.utils.registerEventHandler(a,"mouseout",function(){d.hide()});
ko.utils.registerEventHandler(d,"click",function(){var a=$(this).hasClass("up"),c=Number(b());isNaN(c)&&(c=0);a?b(""+(c+1)):0<c&&b(""+(c-1));return!1})},update:function(a,c){var b=c();c="";if(b)if(b=Number(ko.utils.unwrapObservable(b)),isNaN(b))$(a).html("");else{$(a).empty();for(i=0;i<b;i++)c+='<i class="icon-ok"></i>';$(a).html(c)}}};
ko.extenders.async=function(a,c){var b=ko.observable(c),d;b.inProgress=ko.observable(!1);ko.computed(function(){d&&(d.reject(),d=null);var c=a();c&&"function"==typeof c.done?(b.inProgress(!0),d=$.Deferred().done(function(a){b.inProgress(!1);b(a)}),c.done(d.resolve)):b(c)});return b};ko.bindingHandlers.fileUploadNoImage={init:function(a,c){var b={};$.extend(b,{autoUpload:!0,forceIframeTransport:!0},c());$(a).fileupload(b)}};
ko.bindingHandlers.foreachprop={transformObject:function(a){var c=[],b;for(b in a)a.hasOwnProperty(b)&&c.push({key:b,value:a[b]});return c},init:function(a,c,b,d,e){c=ko.utils.unwrapObservable(c());c=ko.bindingHandlers.foreachprop.transformObject(c);ko.applyBindingsToNode(a,{foreach:c});return{controlsDescendantBindings:!0}}};
ko.bindingHandlers.sortIcon={update:function(a,c,b,d,e){a=$(a);b=a.data("column");d=a.find("i");e="icon-blank";c=ko.utils.unwrapObservable(c());c.by()===b&&(e="desc"===c.order()?"icon-chevron-down":"icon-chevron-up");0===d.length&&(d=$("<i class='icon-blank'></i>").appendTo(a));d.removeClass("icon-chevron-down").removeClass("icon-chevron-up").removeClass("icon-blank").addClass(e)}};
ko.bindingHandlers.fusedAutocomplete={init:function(a,c){c=c();var b={},d=ko.utils.unwrapObservable(c.source);b.source=function(b,c){$(a).addClass("ac_loading");$.ajax({url:d,dataType:"json",data:{q:b.term},success:function(a){a=$.map(a.autoCompleteList,function(a){return{label:a.name,value:a.name,source:a}});c(a)},error:function(){items=[{label:"Error during species lookup",value:b.term,source:{listId:"error-unmatched",name:b.term}}];c(items)},complete:function(){$(a).removeClass("ac_loading")}})};
b.select=function(a,b){a=b.item;c.name(a.source.name);c.guid(a.source.guid)};$(a).autocomplete(b).data("ui-autocomplete")||(b={},b.source=d,b.matchSubset=!1,b.formatItem=function(a,b,c){return a.name},b.highlight=!1,b.parse=function(a){var b=[];a=a.autoCompleteList;for(var c=0;c<a.length;c++)b[c]={data:a[c],value:a[c],result:a[c].name};return b},$(a).autocomplete(b.source,b).result(function(a,b,d){b&&(c.name(b.name),c.guid(b.guid))}))}};
ko.bindingHandlers.autocomplete={init:function(a,c){var b=c(),d=ko.utils.unwrapObservable(b.url),e=ko.utils.unwrapObservable(b.listId),f=ko.utils.unwrapObservable(b.valueChangeCallback);c={source:function(b,c){$(a).addClass("ac_loading");void 0!==f&&f(b.term);var g={q:b.term};e&&$.extend(g,{druid:e});$.ajax({url:d,dataType:"json",data:g,success:function(a){a=$.map(a.autoCompleteList,function(a){return{label:a.name,value:a.name,source:a}});a=[{label:"Missing or unidentified species",value:b.term,source:{listId:"unmatched",
name:b.term}}].concat(a);c(a)},error:function(){items=[{label:"Error during species lookup",value:b.term,source:{listId:"error-unmatched",name:b.term}}];c(items)},complete:function(){$(a).removeClass("ac_loading")}})},select:function(a,c){ko.utils.unwrapObservable(b.result)(a,c.item.source)}};var g=ko.utils.unwrapObservable(b.render);g&&$(a).autocomplete(c).data("ui-autocomplete")?$(a).autocomplete(c).data("ui-autocomplete")._renderItem=function(a,b){return $("<li></li>").html(g(b.source)).appendTo(a)}:
$(a).autocomplete(c)}};ko.dirtyFlag=function(a,c){var b=function(){},d=ko.observable(c||!1),e=function(){return"function"===typeof a.modelAsJSON?a.modelAsJSON():ko.toJSON(a)},f=ko.observable(e());b.isDirty=ko.dependentObservable(function(){return d()||f()!==e()});b.reset=function(){f(e());d(!1)};return b};
ko.simpleDirtyFlag=function(a){var c=ko.observable(!1),b=function(){};b.isDirty=ko.computed(function(){return c()?!0:("function"===typeof a.modelAsJSON?a.modelAsJSON():ko.toJSON(a),c(!0),!1)});b.reset=function(){c(!1)};return b};
ko.vetoableObservable=function(a,c,b,d){var e=ko.observable(a),f="function"===typeof c?c:function(){return window.confirm(c)};return ko.dependentObservable({read:e,write:function(a){e()===a||void 0===e()&&""===a||(f()?(e(a),void 0!==b&&b()):(e.notifySubscribers(),void 0!==d&&d()))}})};
ko.extenders.currency=function(a,c){var b;void 0!==c&&(b=c.currencySymbol);a.formattedCurrency=ko.computed(function(){var c=a(),e=isNaN(e=Math.abs(e))?2:e,f=void 0==f?".":f,g=void 0==g?",":g,k=0>c?"-":"",n=void 0==b?"$":b,l=parseInt(c=Math.abs(+c||0).toFixed(e))+"",h=3<(h=l.length)?h%3:0;return n+k+(h?l.substr(0,h)+g:"")+l.substr(h).replace(/(\d{3})(?=\d)/g,"$1"+g)+(e?f+Math.abs(c-l).toFixed(e).slice(2):"")});return a};
function exclusive(a,c,b,d){d=$("#"+c[b+2]).val();a=a.val();c=c[b+3];return""!==d&&""!==a?c:!0}ko.extenders.markdown=function(a,c){var b=new window.Showdown.converter,d=window.WMDEditor.defaults.tagFilter;a.markdownToHtml=ko.computed(function(){var c=a(),c=c?c.replace(/<[^<>]*>?/gi,function(a){return a.match(d.allowedTags)||a.match(d.patternLink)||a.match(d.patternImage)||a.match(d.patternAudio)?a:""}):"";return b.makeHtml(c)});return a};
ko.bindingHandlers.stagedImageUpload={init:function(a,c,b,d,e){var f=ko.observable(),g=ko.observable(),k=ko.observable(),n=ko.observable(!0);b={size:f,progress:g,error:k,complete:n};e=e.createChildContext(e);ko.utils.extend(e,b);var l=c(),h=$(a);c=h.data("role");b=h.data("owner-type");d=h.data("owner-id");var h=h.data("url"),p={};p[b]=d;var m={url:h,role:c,owner:p},m=$.extend({},{maxWidth:300,minWidth:150,minHeight:150,maxHeight:300,previewSelector:".preview"},m);$(a).fileupload({url:m.url,autoUpload:!0,
forceIframeTransport:!0}).on("fileuploadadd",function(a,b){n(!1);g(1)}).on("fileuploadprocessalways",function(b,c){c.files[0].preview&&void 0!==m.previewSelector&&$(a).parent().find(m.previewSelector).append(c.files[0].preview)}).on("fileuploadprogressall",function(a,b){g(Math.floor(b.loaded/b.total*100));f(b.total)}).on("fileuploaddone",function(a,b){a=$("pre",b.result).text();a=$.parseJSON(a);a||(a={},k("No response from server"));a.files[0]?(l.push(ko.bindingHandlers.stagedImageUpload.toDocument(a.files[0],
m)),n(!0)):k(a.error)}).on("fileuploadfail",function(a,b){k(b.errorThrown)});ko.applyBindingsToDescendants(e,a);return{controlsDescendantBindings:!0}},toDocument:function(a,c){return $.extend({},{thumbnailUrl:a.thumbnail_url,url:a.url,contentType:a.contentType,filename:a.name,filesize:a.size,dateTaken:a.isoDate,lat:a.decimalLatitude,lng:a.decimalLongitude,name:a.name,type:"image",role:c.role},c.owner)}};
var ACTIVITY_PROGRESS_CLASSES={planned:"btn-warning",started:"btn-success",finished:"btn-info",deferred:"btn-danger",cancelled:"btn-inverse"};function activityProgressClass(a){return ACTIVITY_PROGRESS_CLASSES[a]}ko.subscribable.fn.subscribeChanged=function(a){var c=this.peek();return this.subscribe(function(b){var d=c;c=b;a(b,d)})};
ko.extenders.numericString=function(a,c){var b=ko.computed({read:a,write:function(b){var e=b;"string"===typeof e&&(e=b.replace(/,|\$/g,""));var f=a(),g=Math.pow(10,c),k=isNaN(e)?0:parseFloat(+e),g=Math.round(k*g)/g;g.toString()!==f||isNaN(e)?a(isNaN(e)?b:g.toString()):b!==f&&a.notifySubscribers(g.toString())}}).extend({notify:"always"});b(a());return b};
ko.extenders.url=function(a){var c=ko.pureComputed({read:a,write:function(b){b="string"==typeof b&&0>b.indexOf("://")?"http://"+b:b;a(b)}});c(a());return c};ko.extenders.jsonText=function(a,c){a.fromJSON=function(b){b&&a(vkbeautify.json(JSON.stringify(b),2))};a.toJSON=function(){return a()?JSON.parse(a()):null};c&&a.fromJSON(c)};

==> ecodata-3.1.1-exec.jar: assets/knockout-dates.js <==
//# sourceMappingURL=knockout-dates.js.map
var process=process||{env:{NODE_ENV:"development"}};
(function(){Date.prototype.toISOStringNoMillis=function(){function a(a){return 10>a?"0"+a:a}return this.getUTCFullYear()+"-"+a(this.getUTCMonth()+1)+"-"+a(this.getUTCDate())+"T"+a(this.getUTCHours())+":"+a(this.getUTCMinutes())+":"+a(this.getUTCSeconds())+"Z"};var a=new Date("2011-06-02T09:34:29+02:00");Date.fromISO=a&&1307000069E3===+a?function(a){return new Date(a)}:function(a){var b=/^(\d{4}\-\d\d\-\d\d([tT ][\d:\.]*)?)([zZ]|([+\-])(\d\d):(\d\d))?$/.exec(a)||[];if(b[1]){a=b[1].split(/\D/);var c=
0;for(var e=a.length;c<e;c++)a[c]=parseInt(a[c],10)||0;--a[1];a=new Date(Date.UTC.apply(Date,a));if(!a.getDate())return NaN;b[5]&&(c=60*parseInt(b[5],10),b[6]&&(c+=parseInt(b[6],10)),"+"==b[4]&&(c*=-1),c&&a.setUTCMinutes(a.getUTCMinutes()+c));return a}return NaN}})();function isValidDate(a){return"[object Date]"!==Object.prototype.toString.call(a)?!1:!isNaN(a.getTime())}
function convertToSimpleDate(a,c){if(!a)return"";var b=a;"string"===typeof a&&(b=Date.fromISO(a));if(!isValidDate(b))return"";pad(b.getDate(),2);pad(b.getMonth()+1,2);b.getFullYear();a=pad(b.getDate(),2)+"-"+pad(b.getMonth()+1,2)+"-"+b.getFullYear();c&&(a=a+" "+pad(b.getHours(),2)+":"+pad(b.getMinutes(),2));return a}
function convertToIsoDate(a){if("string"===typeof a){if(20===a.length&&"Z"===a.charAt(19))return a;if(9<a.length){var c=a.substr(6,4),b=Number(a.substr(3,2))-1,d=a.substr(0,2),e=12<a.length?a.substr(11,2):0;a=15<a.length?a.substr(14,2):0;c=new Date(c,b,d,e,a);return isValidDate(c)?c.toISOStringNoMillis():""}return""}return"object"===typeof a?isValidDate(a)?a.toISOStringNoMillis():"":""}
function stringToDate(a){if("string"===typeof a){if(20===a.length&&"Z"===a.charAt(19))return Date.fromISO(a);if(9<a.length){var c=a.substr(6,4),b=Number(a.substr(3,2))-1,d=a.substr(0,2),e=12<a.length?a.substr(11,2):0;a=15<a.length?a.substr(14,2):0;return new Date(c,b,d,e,a)}}else if("object"===typeof a)return a}
(function(){ko.bindingHandlers.stopBinding={init:function(){return{controlsDescendantBindings:!0}}};ko.virtualElements.allowedBindings.stopBinding=!0;ko.extenders.simpleDate=function(a,c){a.date=ko.computed({read:function(){return Date.fromISO(a())},write:function(b){if(b){var c=a();b=convertToIsoDate(b);b!==c&&a(b)}else a("")}});a.formattedDate=ko.computed({read:function(){return convertToSimpleDate(a(),c)},write:function(b){if(b){var c=a();b=convertToIsoDate(b);b!==c&&a(b)}}});a.date(a());a.formattedDate(a());
return a};ko.bindingHandlers.datepicker={init:function(a,c,b){var d=$(a);b=ko.utils.unwrapObservable(c());b=convertToSimpleDate(b);d.is("input")?d.val(b):d.data("date",b);d.datepicker({format:"dd-mm-yyyy",autoclose:!0});d.parent().find(".open-datepicker").click(function(){d.datepicker("show")});b=function(a){var b=c();ko.isObservable(b)&&b(a.date)};ko.utils.registerEventHandler(a,"changeDate",b);ko.utils.registerEventHandler(a,"hide",b);ko.utils.registerEventHandler(a,"change",function(){var b=c();
ko.isObservable(b)&&(b(stringToDate(a.value)),$(a).trigger("blur"))})},update:function(a,c){if(a=$(a).data("datepicker"))c=ko.utils.unwrapObservable(c()),a.date=c,isNaN(a.date)||a.setDate(a.date)}}})();function pad(a,c){for(a=""+a;a.length<c;)a="0"+a;return a}ko.protectedObservable=function(a){var c=ko.observable(a),b=a;a=ko.dependentObservable({read:c,write:function(a){c(a)}});a.commit=function(){b=c()};a.reset=function(){c(b)};return a};
ko.bindingHandlers.clickToPickDate={init:function(a,c,b,d){var e=c(),f=$(a).attr("data-prompt")||"Click to edit";c=$('<i class="icon-calendar open-datepicker" title="Click to change date"></i>');e.originalValue=e.date();e.hasChanged=ko.computed(function(){var a=e.originalValue.getTime(),b=e.date().getTime();return a!=b&&(!isNaN(a)||!isNaN(b))});$(a).parent().append(c);ko.applyBindingsToNode(a,{text:ko.computed(function(){return""!==ko.utils.unwrapObservable(e)?e.formattedDate():f}),datepicker:e.date})}};
ko.bindingHandlers.clickToEdit={init:function(a,c){var b=c();c=document.createElement("a");var d=document.createElement("input"),e=$(a).attr("data-edit-on-dblclick"),f=$(a).attr("data-prompt")||(e?"Double-click to edit":"Click to edit");$(c).addClass($(a).attr("data-link-class"));$(d).addClass($(a).attr("data-input-class"));a.appendChild(c);a.appendChild(d);b.editing=ko.observable(!1);b.stopEditing=function(){$(d).blur();b.editing(!1)};a={text:ko.computed(function(){var a=ko.utils.unwrapObservable(b);
return""!==a?a:f}),visible:ko.computed(function(){return!b.editing()})};e?a.event={dblclick:b.editing.bind(null,!0)}:a.click=b.editing.bind(null,!0);ko.applyBindingsToNode(c,a);ko.applyBindingsToNode(d,{value:b,visible:b.editing,hasfocus:b.editing});$(d).keydown(function(a){13===a.which&&b.stopEditing()})}};
ko.bindingHandlers.ticks={init:function(a,c){var b=c();a=$(a).parent();c=$('<div class="tick-controls btn-group btn-group-vertical"></div>');a.css("padding","4px");c.append($('<button class="up btn btn-mini"><i class="icon-chevron-up"></i></button>'));c.append($('<button class="down btn btn-mini"><i class="icon-chevron-down"></i></button>'));a.append(c);var d=a.find("button");d.hide();ko.utils.registerEventHandler(a,"mouseover",function(){d.show()});ko.utils.registerEventHandler(a,"mouseout",function(){d.hide()});
ko.utils.registerEventHandler(d,"click",function(){var a=$(this).hasClass("up"),c=Number(b());isNaN(c)&&(c=0);a?b(""+(c+1)):0<c&&b(""+(c-1));return!1})},update:function(a,c){var b=c();c="";if(b)if(b=Number(ko.utils.unwrapObservable(b)),isNaN(b))$(a).html("");else{$(a).empty();for(i=0;i<b;i++)c+='<i class="icon-ok"></i>';$(a).html(c)}}};
ko.extenders.async=function(a,c){var b=ko.observable(c),d;b.inProgress=ko.observable(!1);ko.computed(function(){d&&(d.reject(),d=null);var c=a();c&&"function"==typeof c.done?(b.inProgress(!0),d=$.Deferred().done(function(a){b.inProgress(!1);b(a)}),c.done(d.resolve)):b(c)});return b};ko.bindingHandlers.fileUploadNoImage={init:function(a,c){var b={};$.extend(b,{autoUpload:!0,forceIframeTransport:!0},c());$(a).fileupload(b)}};
ko.bindingHandlers.foreachprop={transformObject:function(a){var c=[],b;for(b in a)a.hasOwnProperty(b)&&c.push({key:b,value:a[b]});return c},init:function(a,c,b,d,e){c=ko.utils.unwrapObservable(c());c=ko.bindingHandlers.foreachprop.transformObject(c);ko.applyBindingsToNode(a,{foreach:c});return{controlsDescendantBindings:!0}}};
ko.bindingHandlers.sortIcon={update:function(a,c,b,d,e){a=$(a);b=a.data("column");d=a.find("i");e="icon-blank";c=ko.utils.unwrapObservable(c());c.by()===b&&(e="desc"===c.order()?"icon-chevron-down":"icon-chevron-up");0===d.length&&(d=$("<i class='icon-blank'></i>").appendTo(a));d.removeClass("icon-chevron-down").removeClass("icon-chevron-up").removeClass("icon-blank").addClass(e)}};
ko.bindingHandlers.fusedAutocomplete={init:function(a,c){c=c();var b={},d=ko.utils.unwrapObservable(c.source);b.source=function(b,c){$(a).addClass("ac_loading");$.ajax({url:d,dataType:"json",data:{q:b.term},success:function(a){a=$.map(a.autoCompleteList,function(a){return{label:a.name,value:a.name,source:a}});c(a)},error:function(){items=[{label:"Error during species lookup",value:b.term,source:{listId:"error-unmatched",name:b.term}}];c(items)},complete:function(){$(a).removeClass("ac_loading")}})};
b.select=function(a,b){a=b.item;c.name(a.source.name);c.guid(a.source.guid)};$(a).autocomplete(b).data("ui-autocomplete")||(b={},b.source=d,b.matchSubset=!1,b.formatItem=function(a,b,c){return a.name},b.highlight=!1,b.parse=function(a){var b=[];a=a.autoCompleteList;for(var c=0;c<a.length;c++)b[c]={data:a[c],value:a[c],result:a[c].name};return b},$(a).autocomplete(b.source,b).result(function(a,b,d){b&&(c.name(b.name),c.guid(b.guid))}))}};
ko.bindingHandlers.autocomplete={init:function(a,c){var b=c(),d=ko.utils.unwrapObservable(b.url),e=ko.utils.unwrapObservable(b.listId),f=ko.utils.unwrapObservable(b.valueChangeCallback);c={source:function(b,c){$(a).addClass("ac_loading");void 0!==f&&f(b.term);var g={q:b.term};e&&$.extend(g,{druid:e});$.ajax({url:d,dataType:"json",data:g,success:function(a){a=$.map(a.autoCompleteList,function(a){return{label:a.name,value:a.name,source:a}});a=[{label:"Missing or unidentified species",value:b.term,source:{listId:"unmatched",
name:b.term}}].concat(a);c(a)},error:function(){items=[{label:"Error during species lookup",value:b.term,source:{listId:"error-unmatched",name:b.term}}];c(items)},complete:function(){$(a).removeClass("ac_loading")}})},select:function(a,c){ko.utils.unwrapObservable(b.result)(a,c.item.source)}};var g=ko.utils.unwrapObservable(b.render);g&&$(a).autocomplete(c).data("ui-autocomplete")?$(a).autocomplete(c).data("ui-autocomplete")._renderItem=function(a,b){return $("<li></li>").html(g(b.source)).appendTo(a)}:
$(a).autocomplete(c)}};ko.dirtyFlag=function(a,c){var b=function(){},d=ko.observable(c||!1),e=function(){return"function"===typeof a.modelAsJSON?a.modelAsJSON():ko.toJSON(a)},f=ko.observable(e());b.isDirty=ko.dependentObservable(function(){return d()||f()!==e()});b.reset=function(){f(e());d(!1)};return b};
ko.simpleDirtyFlag=function(a){var c=ko.observable(!1),b=function(){};b.isDirty=ko.computed(function(){return c()?!0:("function"===typeof a.modelAsJSON?a.modelAsJSON():ko.toJSON(a),c(!0),!1)});b.reset=function(){c(!1)};return b};
ko.vetoableObservable=function(a,c,b,d){var e=ko.observable(a),f="function"===typeof c?c:function(){return window.confirm(c)};return ko.dependentObservable({read:e,write:function(a){e()===a||void 0===e()&&""===a||(f()?(e(a),void 0!==b&&b()):(e.notifySubscribers(),void 0!==d&&d()))}})};
ko.extenders.currency=function(a,c){if(void 0!==c)var b=c.currencySymbol;a.formattedCurrency=ko.computed(function(){var c=a(),e=isNaN(e=Math.abs(e))?2:e,f=void 0==f?".":f,g=void 0==g?",":g,k=0>c?"-":"",n=void 0==b?"$":b,l=parseInt(c=Math.abs(+c||0).toFixed(e))+"",h=3<(h=l.length)?h%3:0;return n+k+(h?l.substr(0,h)+g:"")+l.substr(h).replace(/(\d{3})(?=\d)/g,"$1"+g)+(e?f+Math.abs(c-l).toFixed(e).slice(2):"")});return a};
function exclusive(a,c,b,d){d=$("#"+c[b+2]).val();a=a.val();c=c[b+3];return""!==d&&""!==a?c:!0}ko.extenders.markdown=function(a,c){var b=new window.Showdown.converter,d=window.WMDEditor.defaults.tagFilter;a.markdownToHtml=ko.computed(function(){var c=a();c=c?c.replace(/<[^<>]*>?/gi,function(a){return a.match(d.allowedTags)||a.match(d.patternLink)||a.match(d.patternImage)||a.match(d.patternAudio)?a:""}):"";return b.makeHtml(c)});return a};
ko.bindingHandlers.stagedImageUpload={init:function(a,c,b,d,e){var f=ko.observable(),g=ko.observable(),k=ko.observable(),n=ko.observable(!0);b={size:f,progress:g,error:k,complete:n};e=e.createChildContext(e);ko.utils.extend(e,b);var l=c(),h=$(a);c=h.data("role");b=h.data("owner-type");d=h.data("owner-id");h=h.data("url");var p={};p[b]=d;var m={url:h,role:c,owner:p};m=$.extend({},{maxWidth:300,minWidth:150,minHeight:150,maxHeight:300,previewSelector:".preview"},m);$(a).fileupload({url:m.url,autoUpload:!0,
forceIframeTransport:!0}).on("fileuploadadd",function(a,b){n(!1);g(1)}).on("fileuploadprocessalways",function(b,c){c.files[0].preview&&void 0!==m.previewSelector&&$(a).parent().find(m.previewSelector).append(c.files[0].preview)}).on("fileuploadprogressall",function(a,b){g(Math.floor(b.loaded/b.total*100));f(b.total)}).on("fileuploaddone",function(a,b){a=$("pre",b.result).text();a=$.parseJSON(a);a||(a={},k("No response from server"));a.files[0]?(l.push(ko.bindingHandlers.stagedImageUpload.toDocument(a.files[0],
m)),n(!0)):k(a.error)}).on("fileuploadfail",function(a,b){k(b.errorThrown)});ko.applyBindingsToDescendants(e,a);return{controlsDescendantBindings:!0}},toDocument:function(a,c){return $.extend({},{thumbnailUrl:a.thumbnail_url,url:a.url,contentType:a.contentType,filename:a.name,filesize:a.size,dateTaken:a.isoDate,lat:a.decimalLatitude,lng:a.decimalLongitude,name:a.name,type:"image",role:c.role},c.owner)}};
var ACTIVITY_PROGRESS_CLASSES={planned:"btn-warning",started:"btn-success",finished:"btn-info",deferred:"btn-danger",cancelled:"btn-inverse"};function activityProgressClass(a){return ACTIVITY_PROGRESS_CLASSES[a]}ko.subscribable.fn.subscribeChanged=function(a){var c=this.peek();return this.subscribe(function(b){var d=c;c=b;a(b,d)})};
ko.extenders.numericString=function(a,c){var b=ko.computed({read:a,write:function(b){var d=b;"string"===typeof d&&(d=b.replace(/,|\$/g,""));var f=a(),g=Math.pow(10,c),k=isNaN(d)?0:parseFloat(+d);g=Math.round(k*g)/g;g.toString()!==f||isNaN(d)?a(isNaN(d)?b:g.toString()):b!==f&&a.notifySubscribers(g.toString())}}).extend({notify:"always"});b(a());return b};
ko.extenders.url=function(a){var c=ko.pureComputed({read:a,write:function(b){b="string"==typeof b&&0>b.indexOf("://")?"http://"+b:b;a(b)}});c(a());return c};ko.extenders.jsonText=function(a,c){a.fromJSON=function(b){b&&a(JSON.stringify(b,null,4))};a.toJSON=function(){return a()?JSON.parse(a()):null};c&&a.fromJSON(c)};
